=== modified file 'utilities/local-latency'
--- utilities/local-latency	2011-08-04 20:26:07 +0000
+++ utilities/local-latency	2011-08-04 20:44:08 +0000
@@ -6,10 +6,10 @@
 import subprocess
 
 from script_commands import (
-    Command,
+    helps,
+    run_subcommand,
     UserError,
     types,
-    helps,
     )
 
 
@@ -29,19 +29,19 @@
        ' sport %d 0xffff flowid 1:3' % port)
 
 
-Command.commands['start'] = start
-
-
 def stop():
     tc('qdisc del dev lo root')
 
 
-Command.commands['stop'] = stop
+subcommands = {
+    'start': start,
+    'stop': stop,
+    }
 
 
 
 if __name__ == "__main__":
     try:
-        Command.run_subcommand(sys.argv[1:])
+        run_subcommand(subcommands, sys.argv[1:])
     except UserError as e:
         sys.stderr.write(str(e)+'\n')

=== modified file 'utilities/script_commands.py'
--- utilities/script_commands.py	2011-08-04 20:26:07 +0000
+++ utilities/script_commands.py	2011-08-04 20:44:08 +0000
@@ -20,8 +20,14 @@
     return add_dict('_helps', **kwargs)
 
 
-
 def get_function_parser(function):
+    """Generate an OptionParser for a function.
+
+    Defaults come from the parameter defaults.
+    For every permitted to provide as an option, the type must be specified,
+    using the types decorator.
+    Help may be specified using the helps decorator.
+    """
     parser = OptionParser()
     args, ignore, ignored, defaults = inspect.getargspec(function)
     for arg in args:
@@ -41,33 +47,31 @@
     return parser
 
 
-class Command:
-    """Base class for subcommands."""
-
-    commands = {}
-
-    @classmethod
-    def parse_args(cls, command, args):
-        if len(args) != 0:
-            raise UserError('Too many arguments.')
-        return {}
-
-    @classmethod
-    def run_from_args(cls, command, cmd_args):
-        parser = get_function_parser(command)
-        options, args = parser.parse_args(cmd_args)
-        kwargs = cls.parse_args(command, args)
-        kwargs.update(options.__dict__)
-        command(**kwargs)
-
-    @classmethod
-    def run_subcommand(cls, argv):
-        if len(argv) < 1:
-            raise UserError('Must supply a command: %s.' %
-                            ', '.join(cls.commands.keys()))
-        try:
-            command = cls.commands[argv[0]]
-        except KeyError:
-            raise UserError('%s invalid.  Valid commands: %s.' %
-                            (argv[0], ', '.join(cls.commands.keys())))
-        cls.run_from_args(command, argv[1:])
+def parse_args(command, args):
+    """Return the positional arguments as a dict."""
+    # TODO: implement!
+    if len(args) != 0:
+        raise UserError('Too many arguments.')
+    return {}
+
+
+def run_from_args(command, cmd_args):
+    """Run a command function using the specified commandline arguments."""
+    parser = get_function_parser(command)
+    options, args = parser.parse_args(cmd_args)
+    kwargs = parse_args(command, args)
+    kwargs.update(options.__dict__)
+    command(**kwargs)
+
+
+def run_subcommand(subcommands, argv):
+    """Run a subcommand as specified by argv."""
+    if len(argv) < 1:
+        raise UserError('Must supply a command: %s.' %
+                        ', '.join(subcommands.keys()))
+    try:
+        command = subcommands[argv[0]]
+    except KeyError:
+        raise UserError('%s invalid.  Valid commands: %s.' %
+                        (argv[0], ', '.join(subcommands.keys())))
+    run_from_args(command, argv[1:])

